## NOTE: Lots of files in various subdirectories have the same name (such as
## "LICENSE") so this short macro allows us to distinguish them by using their
## directory names (from the source tree) as prefixes for the files.
%global add_to_license_files() \
        mkdir -p _license_files ; \
        cp -p %1 _license_files/$(echo '%1' | sed -e 's!/!.!g')

Name:           webkitgtk4
Version:        2.18.5
Release:        1%{?_dist_release}
Summary:        GTK+ Web content engine library

License:        LGPLv2
Group:			System Environment/Libraries
URL:            http://www.webkitgtk.org/
Vendor:         Project Vine
Distribution:   Vine Linux

Source0:        http://webkitgtk.org/releases/webkitgtk-%{version}.tar.xz

Patch3:         webkitgtk-2.5.2-commit_align.patch

BuildRequires:  at-spi2-core-devel
BuildRequires:  bison
BuildRequires:  cairo-devel
BuildRequires:  cmake
BuildRequires:  enchant-devel
BuildRequires:  flex
BuildRequires:  fontconfig-devel
BuildRequires:  freetype-devel
BuildRequires:  geoclue2-devel
BuildRequires:  gettext
BuildRequires:  glib2-devel
BuildRequires:  gobject-introspection-devel
BuildRequires:  gperf
BuildRequires:  gstreamer1-devel
BuildRequires:  gstreamer1-plugins-base-devel
BuildRequires:  gtk2-devel
BuildRequires:  gtk3-devel
BuildRequires:  harfbuzz-icu-devel
BuildRequires:  libicu-devel
BuildRequires:  libjpeg-turbo-devel
BuildRequires:  libpng-devel
BuildRequires:  libsecret-devel
BuildRequires:  libsoup-devel
BuildRequires:  libwebp-devel
BuildRequires:  libxslt-devel
BuildRequires:  libXt-devel
BuildRequires:  mesa-libGL-devel
BuildRequires:  pcre-devel
BuildRequires:  ruby
BuildRequires:  sqlite3-devel
BuildRequires:  libnotify-devel
BuildRequires:  hyphen-devel
%ifarch ppc
BuildRequires:  libatomic
%endif
Requires:       geoclue2

# Require the jsc subpackage
Requires:       %{name}-jsc = %{version}-%{release}

# Obsolete libwebkit2gtk from the webkitgtk3 package
Obsoletes:      libwebkit2gtk < 2.4.5-3
Provides:       libwebkit2gtk = %{version}-%{release}

# Filter out provides for private libraries
%global __provides_exclude_from ^%{_libdir}/webkit2gtk-4\\.0/.*\\.so$

%description
WebKitGTK+ is the port of the portable web rendering engine WebKit to the
GTK+ platform.

This package contains WebKitGTK+ for GTK+ 3.

%package        devel
Summary:        Development files for %{name}
Group:			Development/Libraries
Requires:       %{name} = %{version}-%{release}
Requires:       %{name}-jsc-devel = %{version}-%{release}

%description    devel
The %{name}-devel package contains libraries, build data, and header
files for developing applications that use %{name}.

%package        jsc
Summary:        JavaScript engine from %{name}
Group:			System Environment/Libraries

%description    jsc
This package contains JavaScript engine from %{name}.

%package        jsc-devel
Summary:        Development files for JavaScript engine from %{name}
Group:			Development/Libraries
Requires:       %{name}-jsc = %{version}-%{release}

%description    jsc-devel
The %{name}-jsc-devel package contains libraries, build data, and header
files for developing applications that use JavaScript engine from %{name}.


%prep
%setup -q -n webkitgtk-%{version}
%ifarch %{power64} aarch64 ppc
%patch3 -p1 -b .commit_align
%endif

# Remove bundled libraries
rm -rf Source/ThirdParty/leveldb/
rm -rf Source/ThirdParty/gtest/
rm -rf Source/ThirdParty/qunit/

%build
# binutils-2.23 doesn't support "reduce-memory-overheads"
# Use linker flags to reduce memory consumption
# global optflags %{optflags} -Wl,--no-keep-memory -Wl,--reduce-memory-overheads

%ifarch s390 %{arm}
# Decrease debuginfo verbosity to reduce memory consumption even more
%global optflags %(echo %{optflags} | sed 's/-g /-g1 /')
%endif

%ifarch ppc
# Use linker flag -relax to get WebKit build under ppc(32) with JIT disabled
%global optflags %{optflags} -Wl,-relax -latomic
%endif

%global optflags %{optflags} -DENABLE_YARR_JIT=0

mkdir -p %{_target_platform}
pushd %{_target_platform}
%cmake \
  -DPORT=GTK \
  -DCMAKE_BUILD_TYPE=Release \
  -DENABLE_JIT=OFF \
  -DENABLE_LLINT_C_LOOP=ON \
  ..
popd

make %{?_smp_mflags} -C %{_target_platform}

%install
%make_install -C %{_target_platform}

%find_lang WebKit2GTK-4.0

# Finally, copy over and rename various files for %%license inclusion
%add_to_license_files Source/JavaScriptCore/COPYING.LIB
%add_to_license_files Source/JavaScriptCore/icu/LICENSE
%add_to_license_files Source/ThirdParty/ANGLE/LICENSE
%add_to_license_files Source/ThirdParty/ANGLE/src/third_party/compiler/LICENSE
%add_to_license_files Source/ThirdParty/ANGLE/src/third_party/murmurhash/LICENSE
%add_to_license_files Source/WebCore/icu/LICENSE
%add_to_license_files Source/WebCore/LICENSE-APPLE
%add_to_license_files Source/WebCore/LICENSE-LGPL-2
%add_to_license_files Source/WebCore/LICENSE-LGPL-2.1
%add_to_license_files Source/WebInspectorUI/UserInterface/External/CodeMirror/LICENSE
%add_to_license_files Source/WebInspectorUI/UserInterface/External/Esprima/LICENSE
%add_to_license_files Source/WTF/icu/LICENSE
%add_to_license_files Source/WTF/wtf/dtoa/COPYING
%add_to_license_files Source/WTF/wtf/dtoa/LICENSE

%post -p /sbin/ldconfig
%postun -p /sbin/ldconfig
%post jsc -p /sbin/ldconfig
%postun jsc -p /sbin/ldconfig

%files -f WebKit2GTK-4.0.lang
%license _license_files/*
%{_libdir}/libwebkit2gtk-4.0.so.*
%{_libdir}/girepository-1.0/WebKit2-4.0.typelib
%{_libdir}/girepository-1.0/WebKit2WebExtension-4.0.typelib
%{_libdir}/webkit2gtk-4.0/
%{_libexecdir}/webkit2gtk-4.0/*
%exclude %{_libexecdir}/webkit2gtk-4.0/jsc
%{_bindir}/WebKitWebDriver

%files jsc
%license _license_files/*JavaScriptCore*
%dir %{_libexecdir}/webkit2gtk-4.0/
%{_libexecdir}/webkit2gtk-4.0/jsc
%{_libdir}/libjavascriptcoregtk-4.0.so.*
%{_libdir}/girepository-1.0/JavaScriptCore-4.0.typelib

%files devel
%{_includedir}/webkitgtk-4.0/*
%exclude %{_includedir}/webkitgtk-4.0/JavaScriptCore/
%{_libdir}/libwebkit2gtk-4.0.so
%{_libdir}/pkgconfig/webkit2gtk-4.0.pc
%{_libdir}/pkgconfig/webkit2gtk-web-extension-4.0.pc
%{_datadir}/gir-1.0/WebKit2-4.0.gir
%{_datadir}/gir-1.0/WebKit2WebExtension-4.0.gir

%files jsc-devel
%dir %{_includedir}/webkitgtk-4.0
%{_includedir}/webkitgtk-4.0/JavaScriptCore/
%{_libdir}/libjavascriptcoregtk-4.0.so
%{_libdir}/pkgconfig/javascriptcoregtk-4.0.pc
%{_datadir}/gir-1.0/JavaScriptCore-4.0.gir

%changelog
* Thu Jan 11 2018 Tomohiro "Tomo-p" KATO <tomop@teamgedoh.net> - 2.18.5-1
- new upstream release.
- added subpackages webkitgtk4-jsc{,-devel}.

* Mon Jan 08 2018 Tomohiro "Tomo-p" KATO <tomop@teamgedoh.net> - 2.18.4-1
- new upstream release.

* Wed Jun 29 2016 Tomohiro "Tomo-p" KATO <tomop@teamgedoh.net> - 2.12.3-2
- rebuilt with new toolchain.

* Sun Jun 12 2016 Yoji TOYODA <bsyamato@sea.plala.or.jp> 2.12.3-1
- new upstream release
  (including security fix for CVE-2016-1856,1857)

* Sun May 08 2016 Yoji TOYODA <bsyamato@sea.plala.or.jp> 2.12.2-1
- new upstream release
- remove Patch0
- add BuildRequires: libnotify-devel, hyphen-devel

* Wed Dec 30 2015 Yoji TOYODA <bsyamato@sea.plala.or.jp> 2.8.5-3
- rebuild with gnutls-3.4.7

* Sat Oct 31 2015 Yoji TOYODA <bsyamato@sea.plala.or.jp> 2.8.5-2
- rebuild with icu-56.1

* Mon Aug 17 2015 Yoji TOYODA <bsyamato@sea.plala.or.jp> 2.8.5-1
- new upstream release

* Sun Jul 19 2015 Yoji TOYODA <bsyamato@sea.plala.or.jp> 2.8.4-1
- new upstream release

* Fri May 22 2015 Yoji TOYODA <bsyamato@sea.plala.or.jp> 2.8.3-1
- new upstream release

* Fri May 15 2015 Yoji TOYODA <bsyamato@sea.plala.or.jp> 2.8.2-1
- new upstream release

* Wed Apr 15 2015 Yoji TOYODA <bsyamato@sea.plala.or.jp> 2.8.1-1
- new upstream release

* Sun Mar 29 2015 Yoji TOYODA <bsyamato@sea.plala.or.jp> 2.8.0-1
- new upstream release
- update Patch0

* Sun Mar 01 2015 Yoji TOYODA <bsyamato@sea.plala.or.jp> 2.6.5-1
- new upstream release

* Sat Nov 29 2014 Yoji TOYODA <bsyamato@sea.plala.or.jp> 2.6.4-2
- add Group tag

* Mon Nov 24 2014 Yoji TOYODA <bsyamato@sea.plala.or.jp> 2.6.4-1
- new upstream release

* Tue Nov 18 2014 Yoji TOYODA <bsyamato@sea.plala.or.jp> 2.6.3-1
- new upstream release

* Sun Oct 26 2014 Yoji TOYODA <bsyamato@sea.plala.or.jp> 2.6.2-1
- initial build for Vine Linux


* Thu Sep 25 2014 Tomas Popela <tpopela@redhat.com> - 2.6.0-1
- Add the wrongly removed CLoop patch and remove the one that was upstreamed

* Wed Sep 24 2014 Kalev Lember <kalevlember@gmail.com> - 2.6.0-1
- Update to 2.6.0

* Mon Sep 22 2014 Tomas Popela <tpopela@redhat.com> - 2.5.90-1
- Update to 2.5.90

* Tue Aug 26 2014 Kalev Lember <kalevlember@gmail.com> - 2.5.3-7
- Obsolete libwebkit2gtk from the webkitgtk3 package

* Tue Aug 26 2014 David Tardon <dtardon@redhat.com> - 2.5.3-6
- rebuild for ICU 53.1

* Mon Aug 25 2014 Tomas Popela <tpopela@redhat.com> - 2.5.3-5
- Add support for secondary arches

* Fri Aug 22 2014 Michael Catanzaro <mcatanzaro@gnome.org> - 2.5.3-4
- Add webkitgtk-2.5.3-toggle-buttons.patch

* Thu Aug 21 2014 Kalev Lember <kalevlember@gmail.com> - 2.5.3-3
- More package review fixes (#1131284)
- Correct the license tag to read LGPLv2
- Filter out provides for private libraries

* Tue Aug 19 2014 Kalev Lember <kalevlember@gmail.com> - 2.5.3-2
- Remove bundled leveldb, gtest, qunit in %%prep (#1131284)

* Fri Aug 15 2014 Kalev Lember <kalevlember@gmail.com> - 2.5.3-1
- Update to 2.5.3

* Fri Aug 01 2014 Kalev Lember <kalevlember@gmail.com> - 2.5.1-1
- Initial Fedora packaging, based on the webkitgtk3 package
